@@ -1,7 +1,7 @@
 package Perinci::Sub::Gen::AccessTable;
 
-our $DATE = '2015-04-09'; # DATE
-our $VERSION = '0.45'; # VERSION
+our $DATE = '2015-04-21'; # DATE
+our $VERSION = '0.46'; # VERSION
 
 use 5.010001;
 use strict;
@@ -72,6 +72,10 @@ sub _add_arg {
         tags => [$tag],
     };
 
+    if ($args{aliases}) {
+        $arg_spec->{cmdline_aliases} = $args{aliases};
+    }
+
     # translation args
     my %xargs = (field => $fname);
 
@@ -127,6 +131,7 @@ sub _gen_meta {
         name        => 'with_field_names',
         type        => 'bool',
         default     => $opts->{default_with_field_names},
+        aliases     => $opts->{with_field_names_aliases},
         cat_name    => 'field-selection',
         cat_text    => N__('field selection'),
         summary     => N__('Return field names in each record (as hash/'.
@@ -145,6 +150,7 @@ _
         name        => 'detail',
         type        => 'bool',
         default     => $opts->{default_detail} // 0,
+        aliases     => $opts->{detail_aliases},
         cat_name    => 'field-selection',
         cat_text    => N__('field selection'),
         summary     => N__('Return array of full records instead of '.
@@ -161,6 +167,7 @@ _
         name        => 'fields',
         type        => ['array*' => {of=>'str*'}],
         default     => $opts->{default_fields},
+        aliases     => $opts->{fields_aliases},
         cat_name    => 'field-selection',
         cat_text    => N__('field selection'),
         summary     => N__('Select fields to return'),
@@ -171,6 +178,7 @@ _
         name        => 'sort',
         type        => 'str',
         default     => $opts->{default_sort},
+        aliases     => $opts->{sort_aliases},
         cat_name    => 'ordering',
         cat_text    => N__('ordering'),
         summary     => N__('Order records according to certain field(s)'),
@@ -187,6 +195,7 @@ _
         name        => 'random',
         type        => 'bool',
         default     => $opts->{default_random} // 0,
+        aliases     => $opts->{random_aliases},
         cat_name    => 'ordering',
         cat_text    => N__('ordering'),
         summary     => N__('Return records in random order'),
@@ -197,6 +206,7 @@ _
         name        => 'result_limit',
         type        => 'int',
         default     => $opts->{default_result_limit},
+        aliases     => $opts->{result_limit_aliases},
         cat_name    => 'paging',
         cat_text    => N__('paging'),
         summary     => N__('Only return a certain number of records'),
@@ -205,6 +215,7 @@ _
         func_meta   => $func_meta,
         langs       => $langs,
         name        => 'result_start',
+        aliases     => $opts->{result_start_aliases},
         type        => 'int',
         default     => 1,
         cat_name    => 'paging',
@@ -214,7 +225,8 @@ _
     _add_arg(
         func_meta   => $func_meta,
         langs       => $langs,
-        name        => 'q',
+        name        => 'query',
+        aliases     => $opts->{query_aliases},
         type        => 'str',
         cat_name    => 'filtering',
         cat_text    => N__('filtering'),
@@ -1295,6 +1307,32 @@ case, the function will return with this return value.
 
 _
         },
+
+        result_limit_aliases => {
+            schema => 'hash*',
+        },
+        result_start_aliases => {
+            schema => 'hash*',
+        },
+        with_field_names_aliases => {
+            schema => 'hash*',
+        },
+        detail_aliases => {
+            schema => 'hash*',
+        },
+        fields_aliases => {
+            schema => 'hash*',
+        },
+        sort_aliases => {
+            schema => 'hash*',
+        },
+        random_aliases => {
+            schema => 'hash*',
+        },
+        query_aliases => {
+            schema => 'hash*',
+        },
+
     }, # args
     result => {
         summary => 'A hash containing generated function, metadata',
@@ -1356,12 +1394,28 @@ sub gen_read_table_func {
         summary                    => $args{summary},
         description                => $args{description},
         langs                      => $args{langs} // ['en_US'],
+
         default_detail             => $args{default_detail},
+        detail_aliases             => $args{detail_cmdline_aliases} // {l=>{}},
+
         default_with_field_names   => $args{default_with_field_names},
+        with_field_names_aliases   => $args{with_field_names_aliases},
+
         default_fields             => $args{default_fields},
+        fields_aliases             => $args{fields_aliases},
+
         default_sort               => $args{default_sort},
+        sort_aliases               => $args{sort_aliases},
+
         default_random             => $args{default_random},
+        random_aliases             => $args{random_aliases},
+
         default_result_limit       => $args{default_result_limit},
+        result_limit_aliases       => $args{result_limit_aliases},
+
+        result_start_aliases       => $args{result_start_aliases},
+        query_aliases              => $args{query_aliases} // {q=>{}},
+
         enable_filtering           => $args{enable_filtering} // 1,
         enable_search              => $args{enable_search} // 1,
         custom_search              => $args{custom_search},
@@ -1413,7 +1467,7 @@ Perinci::Sub::Gen::AccessTable - Generate function (and its metadata) to read ta
 
 =head1 VERSION
 
-This document describes version 0.45 of Perinci::Sub::Gen::AccessTable (from Perl distribution Perinci-Sub-Gen-AccessTable), released on 2015-04-09.
+This document describes version 0.46 of Perinci::Sub::Gen::AccessTable (from Perl distribution Perinci-Sub-Gen-AccessTable), released on 2015-04-21.
 
 =head1 SYNOPSIS
 
@@ -1682,6 +1736,8 @@ Supply default 'with_field_names' value in generated function's metadata.
 
 Generated function's description.
 
+=item * B<detail_aliases> => I<hash>
+
 =item * B<enable_field_selection> => I<bool> (default: 1)
 
 Decide whether generated function will support field selection (the `fields` argument).
@@ -1714,6 +1770,8 @@ Filtering must also be enabled (C<enable_filtering>).
 
 Extra arguments for the generated function.
 
+=item * B<fields_aliases> => I<hash>
+
 =item * B<hooks> => I<hash>
 
 Supply hooks.
@@ -1775,6 +1833,16 @@ supply this if you set C<install> to false.
 
 If not specified, caller's package will be used by default.
 
+=item * B<query_aliases> => I<hash>
+
+=item * B<random_aliases> => I<hash>
+
+=item * B<result_limit_aliases> => I<hash>
+
+=item * B<result_start_aliases> => I<hash>
+
+=item * B<sort_aliases> => I<hash>
+
 =item * B<summary> => I<str>
 
 Generated function's summary.
@@ -1822,6 +1890,8 @@ boolean stating whether field can be sorted, default is true), 'filterable' (a
 boolean stating whether field can be mentioned in filter options, default is
 true).
 
+=item * B<with_field_names_aliases> => I<hash>
+
 =item * B<word_search> => I<bool> (default: 0)
 
 Decide whether generated function will perform word searching instead of string searching.
